@@ -16,13 +16,10 @@
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
 
-    KLocalizedString::setApplicationDomain("yakuake");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("yakuake"));
 
     KAboutData aboutData(QStringLiteral("yakuake"),
                          xi18nc("@title", "<application>Yakuake</application>"),
